import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';

class SplitScreen extends StatelessWidget {
  final Widget leftChild;
  final Widget rightChild;
  final Gradient? gradient;
  final Widget? footer;
  final Color? backgroundColor;
  final Image? logo;
  final Image? lightLogo;
  final double? logoHeight;
  final double? footerHeight;
  final EdgeInsetsGeometry? logoPadding;

  const SplitScreen({
    Key? key,
    required this.leftChild,
    required this.rightChild,
    this.gradient,
    this.footer,
    this.backgroundColor,
    this.logo,
    this.lightLogo,
    this.logoHeight,
    this.logoPadding,
    this.footerHeight,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: backgroundColor ?? defaultBackgroundColor,
      body: SafeArea(
        child: SingleChildScrollView(
          child: Container(
            constraints:
                BoxConstraints(minHeight: MediaQuery.of(context).size.height),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                if (logo != null && !Responsive.isDesktop(context))
                  Padding(
                    padding: logoPadding ?? EdgeInsets.zero,
                    child: Align(
                      child: SizedBox(
                        height: logoHeight ?? logo?.height,
                        child: logo,
                      ),
                      alignment: Alignment.topLeft,
                    ),
                  ),
                IntrinsicHeight(
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      if (Responsive.isDesktop(context))
                        Expanded(
                          flex: 1,
                          child: Container(
                            constraints: BoxConstraints(
                                minHeight: MediaQuery.of(context).size.height -
                                    (footerHeight ?? 0)),
                            decoration: BoxDecoration(
                              gradient: gradient ??
                                  const LinearGradient(colors: darkGradient),
                            ),
                            child: Column(
                              children: [
                                if (Responsive.isDesktop(context) &&
                                    (logo != null || lightLogo != null))
                                  Padding(
                                    padding: logoPadding ?? EdgeInsets.zero,
                                    child: Align(
                                      child: SizedBox(
                                        height: logoHeight ??
                                            (lightLogo ?? logo)?.height,
                                        child: lightLogo ?? logo,
                                      ),
                                      alignment: Alignment.topLeft,
                                    ),
                                  ),
                                leftChild,
                              ],
                            ),
                          ),
                        ),
                      Expanded(
                        flex: 1,
                        child: rightChild,
                      ),
                    ],
                  ),
                ),
                Column(
                  children: [
                    if (!Responsive.isDesktop(context))
                      Container(
                        decoration: BoxDecoration(
                          gradient: gradient ??
                              const LinearGradient(colors: darkGradient),
                        ),
                        child: leftChild,
                      ),
                    footer ?? const SizedBox(),
                  ],
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}
